@@ -14,9 +14,7 @@ def pusher_thread(commit_interval):
             logging.debug("Committing {} counters...".format(len(counter_instances)))
 
             for counter_instance in counter_instances:
-                for counter_engine in counter_engines:
-                    counter_instance.commit(counter_engine)
-                counter_instance.commit_finish()
+                counter_instance.commit(counter_engines)
 
         time.sleep(commit_interval)
 
